==> eha_1.2-2.tar.gz: eha/man/plot.Surv.Rd <==
\name{plot.Surv}
\alias{plot.Surv}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Plots of survivor functions.}
\description{
  Kaplan-Meier estimates. If only one curve, confidence limits according
  to Greenwood's formula are drawn.
}
\usage{
plot.Surv(x, strata=NULL, fn = c("cum", "surv", "log", "loglog"),
limits=TRUE, conf=0.95, main=NULL, xlab=NULL, ylab=NULL,
xlim=NULL, ylim=NULL, lty.con=NULL, col.con = NULL, x.axis = TRUE, ...)
}
\arguments{
  \item{x}{A \code{Surv} object.}
  \item{strata}{Defines a partition of the data. One survivor function
    for each level of \code{strata} is drawn.}
  \item{fn}{Which type of plot?}
  \item{limits}{If TRUE, and if the number of curves is one, confidence
    limits are drawn.}
  \item{conf}{The confidence level for the confidence limits.}
  \item{main}{A heading for the plot.}
  \item{xlab}{Label on the x axis.}
  \item{ylab}{Label on the y-axis.}
  \item{xlim}{Horizontal plot limits. If NULL, calculated by the function.}
  \item{ylim}{Vertical plot limits. If NULL, set to \code{c(0, 1)}}
  \item{lty.con}{Line type of confidence bands.}
  \item{col.con}{Color of confidence bands.}
  \item{x.axis}{Should \code{abline(h=0)} be drawn?}
  \item{...}{Anything that \code{plot} likes...}
}
\details{
Left truncation is allowed. Note, though, that this fact may result in
strange estimated curves due to lack of data in certain (low) ages.
}
\value{
No value is returned.
}
%\references{}
\author{\enc{Gran Brostrm}{George Bridgewater}}
%\note{ ~~further notes~~ }

% ~Make other sections like WARNING with \section{WARNING }{....} ~

\examples{
time0 <- numeric(50)
group <- c(rep(0, 25), rep(1, 25))
time1 <- rexp( 50, exp(group) )
event <- rep(1, 50)
plot.Surv(Surv(time0, time1, event), strata = group)
}
\keyword{survival}

==> eha_1.3-0.tar.gz: eha/man/plot.Surv.Rd <==
\name{plot.Surv}
\alias{plot.Surv}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Plots of survivor functions.}
\description{
  Kaplan-Meier estimates. If only one curve, confidence limits according
  to Greenwood's formula are drawn.
}
\usage{
plot.Surv(x, strata=NULL, fn = c("cum", "surv", "log", "loglog"),
limits=TRUE, conf=0.95, main=NULL, xlab=NULL, ylab=NULL,
xlim=NULL, ylim=NULL, lty.con=NULL, col.con = NULL, x.axis = TRUE, ...)
}
\arguments{
  \item{x}{A \code{Surv} object.}
  \item{strata}{Defines a partition of the data. One survivor function
    for each level of \code{strata} is drawn.}
  \item{fn}{Which type of plot?}
  \item{limits}{If TRUE, and if the number of curves is one, confidence
    limits are drawn.}
  \item{conf}{The confidence level for the confidence limits.}
  \item{main}{A heading for the plot.}
  \item{xlab}{Label on the x axis.}
  \item{ylab}{Label on the y-axis.}
  \item{xlim}{Horizontal plot limits. If NULL, calculated by the function.}
  \item{ylim}{Vertical plot limits. If NULL, set to \code{c(0, 1)}}
  \item{lty.con}{Line type of confidence bands.}
  \item{col.con}{Color of confidence bands.}
  \item{x.axis}{Should \code{abline(h=0)} be drawn?}
  \item{...}{Anything that \code{plot} likes...}
}
\details{
Left truncation is allowed. Note, though, that this fact may result in
strange estimated curves due to lack of data in certain (low) ages.
}
\value{
No value is returned.
}
%\references{}
\author{\enc{Göran Broström}{George Bridgewater}}
%\note{ ~~further notes~~ }

% ~Make other sections like WARNING with \section{WARNING }{....} ~

\examples{
time0 <- numeric(50)
group <- c(rep(0, 25), rep(1, 25))
time1 <- rexp( 50, exp(group) )
event <- rep(1, 50)
plot.Surv(Surv(time0, time1, event), strata = group)
}
\keyword{survival}
